/*********************************************************************
*                     SEGGER Microcontroller GmbH                    *
*                        The Embedded Experts                        *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2023 SEGGER Microcontroller GmbH                  *
*                                                                    *
*       Internet: segger.com  Support: support_embos@segger.com      *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system                           *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: V5.18.1.0                                        *
*                                                                    *
**********************************************************************

----------------------------------------------------------------------
File    : BSP.c
Purpose : BSP for RENESAS RL78G13 CPU on GLYN EVBRL78G13 eval board
--------  END-OF-HEADER  ---------------------------------------------
*/

#include "BSP.h"
#include <ior5f100LE.h>

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/
#define LEDPORT_DATA  (P6)
#define LEDPORT_MODE  (PM6)
#define LED0_BIT      (2)
#define LED1_BIT      (3)
#define LED0_MASK     (1uL << LED0_BIT)
#define LED1_MASK     (1uL << LED1_BIT)
#define LED_MASK_ALL  (LED0_MASK | LED1_MASK)

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       BSP_Init()
*/
void BSP_Init(void) {
  LEDPORT_MODE &= ~(LED_MASK_ALL);    // Switch LED-Port to output mode
  LEDPORT_DATA &= ~(LED_MASK_ALL);    // Initially switch off LEDs
}

/*********************************************************************
*
*       BSP_SetLED()
*/
void BSP_SetLED(int Index) {
  LEDPORT_DATA |= (1uL << (Index + LED0_BIT));  // Switch on LED
}

/*********************************************************************
*
*       BSP_ClrLED()
*/
void BSP_ClrLED(int Index) {
  LEDPORT_DATA &= ~(1uL << (Index + LED0_BIT)); // Switch off LED
}

/*********************************************************************
*
*       BSP_ToggleLED()
*/
void BSP_ToggleLED(int Index) {
  if (LEDPORT_DATA & (1uL << (Index + LED0_BIT))) {  
    LEDPORT_DATA &= ~(1uL << (Index + LED0_BIT)); // Switch off LED
  } else {
    LEDPORT_DATA |= (1uL << (Index + LED0_BIT));  // Switch on LED
  }
}

/****** End Of File *************************************************/
