/*********************************************************************
*                     SEGGER Microcontroller GmbH                    *
*                        The Embedded Experts                        *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2023 SEGGER Microcontroller GmbH                  *
*                                                                    *
*       Internet: segger.com  Support: support_embos@segger.com      *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system                           *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: V5.18.1.0                                        *
*                                                                    *
**********************************************************************

----------------------------------------------------------------------
File    : BSP.c
Purpose : BSP for RENESAS RL78L13 CPU on the RSKRL78L13 board

Notes   : The RL78L13 CPU shares the LED port pins with LCD segment
          ports.
          To use the LEDs, remove the RSK LCD APP board
          Port assignents are for 80 pin version
--------  END-OF-HEADER  ---------------------------------------------
*/

#include "BSP.h"

#ifdef __ICCRL78__
  #include <ior5f10wmg.h>
  #include <ior5f10wmg_ext.h>
#elif defined (__GNUC__)
  #include "iodefine.h"
  #include "iodefine_ext.h"
#elif defined (__CCRL__)
  #include "iodefine.h"
#endif

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/
#define LEDPORT_DATA  (P1)
#define LEDPORT_MODE  (PM1)
#define LED0_BIT      (4)
#define LED1_BIT      (5)
#define LED0_MASK     (1uL << LED0_BIT)
#define LED1_MASK     (1uL << LED1_BIT)
#define LED_MASK_ALL  ((LED0_MASK) | (LED1_MASK))

#define LED_MAX_INDEX (1uL)     // We enable two LEDs on the RDK board

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       BSP_Init()
*/
void BSP_Init(void) {
  //
  // Disable the LCD segment outputs, switch to port mode
  //
  PFSEG5 &= ~(1u << 1);
  PFSEG5 &= ~(1u << 0);
  LEDPORT_MODE &= ~(LED_MASK_ALL);    // Switch LED-Port to output mode
  LEDPORT_DATA |=  (LED_MASK_ALL);    // Initially switch off LEDs
}

/*********************************************************************
*
*       BSP_SetLED()
*/
void BSP_SetLED(int Index) {
  if (Index <= (int) LED_MAX_INDEX) {
    LEDPORT_DATA &= ~(1uL << (Index + LED0_BIT));  // Switch on LED
  }
}

/*********************************************************************
*
*       BSP_ClrLED()
*/
void BSP_ClrLED(int Index) {
  if (Index <= (int) LED_MAX_INDEX) {
    LEDPORT_DATA |= (1uL << (Index + LED0_BIT));  // Switch off LED
  }
}

/*********************************************************************
*
*       BSP_ToggleLED()
*/
void BSP_ToggleLED(int Index) {
  if (Index <= (int) LED_MAX_INDEX) {
    if (LEDPORT_DATA & (1uL << (Index + LED0_BIT))) {  // LED is switched off
      LEDPORT_DATA &= ~(1uL << (Index + LED0_BIT));
    } else {
      LEDPORT_DATA |= (1uL << (Index + LED0_BIT));
    }
  }
}

/****** End Of File *************************************************/
